@@ -274,7 +274,7 @@ class NavSoapClient():
                 leaseID=lease_id,
                 leaseName=lease_name,
                 siteLat=lat,
-                siteLong=long,
+                siteLon=long,
                 locationCode=field_office_id,
                 custRespGroup=cust_resp_grp_id
         )
